@@ -1,12 +1,12 @@
 # Extension of pip-accel that deals with dependencies on system packages.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: June 26, 2014
+# Last Change: November 9, 2014
 # URL: https://github.com/paylogic/pip-accel
 
 """
-System package dependency handling
-==================================
+:py:mod:`pip_accel.deps` - System package dependency handling
+=============================================================
 
 Extension of the pip accelerator that deals with dependencies on system
 packages. Currently only Debian Linux and derivative Linux distributions
